trident.loggers package
=======================

Submodules
----------

trident.loggers.BaseLogger module
---------------------------------

.. automodule:: trident.loggers.BaseLogger
   :members:
   :undoc-members:
   :show-inheritance:

trident.loggers.pytorch\_tensorboard module
-------------------------------------------

.. automodule:: trident.loggers.pytorch_tensorboard
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.loggers
   :members:
   :undoc-members:
   :show-inheritance:
